class Foreground:
    default = 38
    blacka = 30
    blackb = 90
    reda = 31
    redb = 91
    greena = 32
    greenb = 92
    yellowa = 33
    yellowb = 93
    bluea = 34
    blueb = 94
    purplea = 35
    purpleb = 95
    cyana = 36
    cyanb = 96
    whitea = 37
    whiteb = 97
    black = blackb
    red = reda
    green = greenb
    yellow = yellowa
    blue = blueb
    purple = purpleb
    cyan = cyana
    white = whiteb


class Background:
    default = 48
    blacka = 40
    blackb = 100
    reda = 41
    redb = 101
    greena = 42
    greenb = 102
    yellowa = 43
    yellowb = 103
    bluea = 44
    blueb = 104
    purplea = 45
    purpleb = 105
    cyana = 46
    cyanb = 106
    whitea = 47
    whiteb = 107
    black = blackb
    red = reda
    green = greenb
    yellow = yellowa
    blue = blueb
    purple = purpleb
    cyan = cyana
    white = whiteb


class Style:
    default = 0
    bold = 1
    italic = 3
    underline = 4
    flash = 5
    throughline = 9
